<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="45"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Passwords do not match</source>
        <translation>Zadání hesla se neshodují</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="54"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>Nápověda je viditelná všem uživatelům. Nepište sem heslo.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="72"/>
        <source>New Password</source>
        <translation>Nové heslo</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="94"/>
        <source>Repeat Password</source>
        <translation>Zadejte heslo znovu</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="102"/>
        <source>Password Hint</source>
        <translation>Nápověda k heslu</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="112"/>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="113"/>
        <source>Optional</source>
        <translation>Volitelné</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="61"/>
        <source>Password cannot be empty</source>
        <translation>Heslo nemůže být prázdné</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="62"/>
        <source>Password must have at least %1 characters</source>
        <translation>Je třeba, aby heslo mělo délku alespoň %1 znaků</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="63"/>
        <source>Password must be no more than %1 characters</source>
        <translation>Heslo může mít délku nejvýše %1 znaků</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="64"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Heslo může obsahovat pouze písmena z anglické abecedy (rozlišují se malá a VELKÁ písmena), číslice a dále ještě speciální symboly (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="65"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>Ne více než %1 znaků, které se tam i zpět čtou stejně (palindrom)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="66"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>Ne více než %1 v abecedě po sobě jdoucí znaky prosím</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="67"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Ne více než %1 opakující se znaky prosím</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="68"/>
        <source>The password should differ from the username</source>
        <translation>Heslo by se mělo lišit od uživatelského jména</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="74"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Je třeba, aby heslo obsahovalo velká a malá písmena z (pouze z anglické abecedy), číslice a symboly (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="75"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Heslo nemůže obsahovat posloupnost více než 4 znaků, která se čte stejně oběma směry (palindrom)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="76"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Do not use common words and combinations as password</source>
        <translation>Jako heslo nepoužívejte běžná slova a jejich kombinace</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="77"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Create a strong password please</source>
        <translation>Vytvořte si odolné heslo prosím</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>It does not meet password rules</source>
        <translation>Nesplňuje pravidla pro hesla</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation>Nemůže být nevyplněné</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="102"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Resetování hesla vymaže údaje uložené v klíčence</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="104"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="207"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="113"/>
        <source>Security Questions</source>
        <translation>Bezpečnostní otázky</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="148"/>
        <source>Reset Password</source>
        <translation>Vynulovat heslo</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="149"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="152"/>
        <source>Reset Password By UOS ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="153"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="203"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="159"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>Resetování hesla vymaže data uložená ve vaší klíčence a měli byste se pak znovu přihlásit. Prosím uložte si rozdělanou práci</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Confirm and Reset</source>
        <translation>Potvrdit a resetovat</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="285"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>Úspěšně vyresetováno, přihlaste se a odemkněte pomocí nového hesla</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="57"/>
        <source>Weak</source>
        <translation>Slabé</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="67"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="77"/>
        <source>Strong</source>
        <translation>Silné</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="109"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="110"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="111"/>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="113"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>Jaký je název města, ve kterém jste se narodili?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="114"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>Jaký je název první školy, kterou jste navštěvovali?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="115"/>
        <source>Who do you love the most in this world?</source>
        <translation>Koho máte na světě nejraději?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="116"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>Jaké je vaše oblíbené zvíře?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="117"/>
        <source>What&apos;s your favorite song?</source>
        <translation>Jaká je vaše oblíbená skladba?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="118"/>
        <source>What&apos;s your nickname?</source>
        <translation>Jaká je vaše přezdívka?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="168"/>
        <source>Wrong answer</source>
        <translation>Nesprávná odpověď</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="183"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Odpověď může být nejvýše 30 znaků dlouhá</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="45"/>
        <source>Phone/Email</source>
        <translation>Telefon/e-mail</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="51"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="118"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="267"/>
        <source>Get Code</source>
        <translation>Získat kód</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="71"/>
        <source>Connecting to the Internet...</source>
        <translation>Připojuje se k internetu…</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="83"/>
        <source>The user account is not linked to UOS ID</source>
        <translation>Uživatelský účet není propojen s UOS ID</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="96"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Síť je odpojena – až opět bude dostupná, zkuste to znovu</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="116"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="117"/>
        <source>Required</source>
        <translation>Vyžadováno</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="158"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <source>Phone/Email format is incorrect</source>
        <translation>Formát telefonu /adresy elektronické pošty je nesprávný</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="229"/>
        <source>System error</source>
        <translation>Systémová chyba</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="231"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation>Platnost přihlášení skončila. Přihlaste se UOS identifikátorem znovu</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="233"/>
        <source>Network error</source>
        <translation>Síťová chyba</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="235"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Přesáhli jste dnešní limit počtu obdržení kódů</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="236"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="270"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="312"/>
        <source>Resend (%1s)</source>
        <translation>Odesláno znovu (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="332"/>
        <source>Failed to get the code</source>
        <translation>Nepodařilo se získat kód</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="357"/>
        <source>Wrong verification code</source>
        <translation>Nesprávný ověřovací kód</translation>
    </message>
</context>
</TS>